==> apache-ignite-2.15.0-src.zip: apache-ignite-2.15.0-src/modules/calcite/src/main/java/org/apache/ignite/internal/processors/query/calcite/prepare/MultiStepDmlPlan.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.query.calcite.prepare;

import org.jetbrains.annotations.Nullable;

/**
 * Distributed dml plan.
 */
public class MultiStepDmlPlan extends AbstractMultiStepPlan {
    /**
     * @param fieldsMeta Fields metadata.
     */
    public MultiStepDmlPlan(
        QueryTemplate queryTemplate,
        FieldsMetadata fieldsMeta,
        @Nullable FieldsMetadata paramsMetadata
    ) {
        super(queryTemplate, fieldsMeta, paramsMetadata);
    }

    /** {@inheritDoc} */
    @Override public Type type() {
        return Type.DML;
    }

    /** {@inheritDoc} */
    @Override public QueryPlan copy() {
        return new MultiStepDmlPlan(queryTemplate, fieldsMetadata, paramsMetadata);
    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/calcite/src/main/java/org/apache/ignite/internal/processors/query/calcite/prepare/MultiStepDmlPlan.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.query.calcite.prepare;

import org.jetbrains.annotations.Nullable;

/**
 * Distributed dml plan.
 */
public class MultiStepDmlPlan extends AbstractMultiStepPlan {
    /**
     * @param fieldsMeta Fields metadata.
     */
    public MultiStepDmlPlan(
        String qry,
        String textPlan,
        QueryTemplate queryTemplate,
        FieldsMetadata fieldsMeta,
        @Nullable FieldsMetadata paramsMetadata
    ) {
        super(qry, textPlan, queryTemplate, fieldsMeta, paramsMetadata);
    }

    /** {@inheritDoc} */
    @Override public Type type() {
        return Type.DML;
    }

    /** {@inheritDoc} */
    @Override public QueryPlan copy() {
        return new MultiStepDmlPlan(query(), textPlan(), queryTemplate, fieldsMetadata, paramsMetadata);
    }
}
